@@ -31,21 +31,21 @@ class DevPrune(FiggyTest):
 
     def cleanup_success(self):
         self.prep_success()
-        self.step(f"Testing: {CLI_NAME} config {Utils.get_first(prune)} --env {DEFAULT_ENV} "
+        self.step(f"Testing: {CLI_NAME} config {prune.name} --env {DEFAULT_ENV} "
               f"--config figcli/test/assets/success/figgy.json --skip-upgrade ")
         time.sleep(30)
-        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(prune)} --env {DEFAULT_ENV} '
+        child = TestUtils.spawn(f'{CLI_NAME} config {prune.name} --env {DEFAULT_ENV} '
                                     f'--config figcli/test/assets/success/figgy.json --skip-upgrade {self.extra_args}')
         child.expect('.*No stray keys.*No remote replication configs.*')
         print("Empty prune, success!")
 
     def cleanup_with_orphans(self):
         self.prep_with_orphans()
-        self.step(f"Testing: {CLI_NAME} config {Utils.get_first(prune)} --env {DEFAULT_ENV} "
+        self.step(f"Testing: {CLI_NAME} config {prune.name} --env {DEFAULT_ENV} "
               f"--config figcli/test/assets/error/figgy.json")
 
         time.sleep(30)
-        child = TestUtils.spawn(f'{CLI_NAME} config {Utils.get_first(prune)} --env {DEFAULT_ENV} '
+        child = TestUtils.spawn(f'{CLI_NAME} config {prune.name} --env {DEFAULT_ENV} '
                                     f'--config figcli/test/assets/error/figgy.json --skip-upgrade {self.extra_args}')
         child.expect('.*/app/ci-test/v1/config11.* exists.*but does not exist.*')
         child.sendline('n')
